@@ -909,7 +909,7 @@ Do not add this to a hook variable."
           "\\(?1:[^\0]+\\)\0"                      ; sha1
           "\\(?5:[^\0]*\\)\0"                      ; author
           "\\(?:\\(?:[^@]+@{\\(?6:[^}]+\\)}\0"     ; date
-          "\\(?10:merge \\|autosave \\|restart \\|[^:]+: \\)?" ; refsub
+          "\\(?10:merge \\|autosave \\|restart \\|[^:\n]+: \\)?" ; refsub
           "\\(?2:.*\\)?\\)\\|\0\\)$"))             ; msg
 
 (defconst magit-reflog-subject-re
@@ -1003,10 +1003,11 @@ Do not add this to a hook variable."
           (insert (propertize hash 'face 'magit-hash) ?\s))
         (when (and refs (not magit-log-show-refname-after-summary))
           (insert (magit-format-ref-labels refs) ?\s))
-        (when refsub
+        (when (eq style 'reflog)
           (insert (format "%-2s " (1- magit-log-count)))
-          (insert (magit-reflog-format-subject
-                   (substring refsub 0 (if (string-match-p ":" refsub) -2 -1)))))
+          (when refsub
+            (insert (magit-reflog-format-subject
+                     (substring refsub 0 (if (string-match-p ":" refsub) -2 -1))))))
         (when msg
           (insert (propertize msg 'face
                               (pcase (and gpg (aref gpg 0))
@@ -1219,7 +1220,7 @@ If there is no blob buffer in the same frame, then do nothing."
 (define-derived-mode magit-log-select-mode magit-log-mode "Magit Select"
   "Mode for selecting a commit from history.
 
-This mode is documented in info node `(magit)Select from log'.
+This mode is documented in info node `(magit)Select from Log'.
 
 \\<magit-mode-map>\
 Type \\[magit-refresh] to refresh the current buffer.
@@ -1503,7 +1504,7 @@ then show the last `magit-log-section-commit-count' commits."
 
 (defun magit-insert-unpulled-cherries ()
   "Insert section showing unpulled commits.
-Like `magit-insert-unpulled-to-upstream' but prefix each commit
+Like `magit-insert-unpulled-from-upstream' but prefix each commit
 which has not been applied yet (i.e. a commit with a patch-id
 not shared with any local commit) with \"+\", and all others with
 \"-\"."
