@@ -1,6 +1,6 @@
 ;;; magit-subtree.el --- subtree support for Magit  -*- lexical-binding: t -*-
 
-;; Copyright (C) 2011-2016  The Magit Project Contributors
+;; Copyright (C) 2011-2017  The Magit Project Contributors
 ;;
 ;; You should have received a copy of the AUTHORS.md file which
 ;; lists all contributors.  If not, see http://magit.vc/authors.
@@ -25,10 +25,11 @@
 
 (require 'magit)
 
+;;; Popup
+
 ;;;###autoload (autoload 'magit-subtree-popup "magit-subtree" nil t)
 (magit-define-popup magit-subtree-popup
   "Popup console for subtree commands."
-  'magit-commands
   :man-page "git-subtree"
   :switches '("Switches for add, merge, push, and pull"
               (?s "Squash" "--squash")
@@ -51,12 +52,6 @@
               (?s "Split"      magit-subtree-split))
   :max-action-columns 3)
 
-(defun magit-subtree-prefix (prompt)
-  (--if-let (--first (string-prefix-p "--prefix=" it)
-                     (magit-subtree-arguments))
-      (substring it 9)
-    (magit-subtree-read-prefix prompt)))
-
 (defun magit-subtree-read-prefix (prompt &optional default)
   (let* ((insert-default-directory nil)
          (topdir (magit-toplevel))
@@ -68,6 +63,14 @@
           (user-error "%s isn't inside the repository at %s" prefix topdir))
       prefix)))
 
+;;; Commands
+
+(defun magit-subtree-prefix (prompt)
+  (--if-let (--first (string-prefix-p "--prefix=" it)
+                     (magit-subtree-arguments))
+      (substring it 9)
+    (magit-subtree-read-prefix prompt)))
+
 (defun magit-subtree-args ()
   (-filter (lambda (arg)
              (if (eq this-command 'magit-subtree-split)
@@ -135,9 +138,5 @@
                      (magit-subtree-args)))
   (magit-git-subtree "split" prefix args commit))
 
-;;; magit-subtree.el ends soon
 (provide 'magit-subtree)
-;; Local Variables:
-;; indent-tabs-mode: nil
-;; End:
 ;;; magit-subtree.el ends here
